function [x,niter]=aitken(phi,x0,tol,nmax,varargin)
%AITKEN Extrapolation d'Aitken
%   [ALPHA,NITER]=AITKEN(PHI,X0) calcule une
%   approximation d'un point fixe ALPHA d'une fonction
%   PHI en partant de la donne initiale X0  l'aide de
%   la mthode d'extrapolation d'Aitken. L'algorithme
%   s'arrte aprs 100 itrations ou quand la valeur
%   absolue de la diffrence entre deux itres
%   conscutives est plus petite que 1.e-04. PHI doit
%   tre dfinie comme une fonction, une fonction
%   inline, une fonction anonyme ou un M-fichier.
%   [ALPHA,NITER]=AITKEN(PHI,X0,TOL,NMAX) permet de
%   dfinir la tolrance pour le critre d'arrt et le
%   nombre maximal d'itrations.
if nargin == 2
    tol = 1.e-04;
    nmax = 100;
elseif nargin == 3
    nmax = 100;
end
x = x0;
diff = tol + 1;
niter = 0;
while niter < nmax & diff >= tol
    gx = feval(phi,x,varargin{:});
    ggx = feval(phi,gx,varargin{:});
    xnew = (x*ggx-gx^2)/(ggx-2*gx+x);
    diff = abs(x-xnew);
    x = xnew;
    niter = niter  + 1;
end
if (niter==nmax & diff>tol)
fprintf(['Ne converge pas aprs avoir atteint le ',...
        'nombre maximum d''itrations\n']);
end
return
