function [xh,uh]=heattheta(xspan,tspan,nstep,mu,...
               u0,g,f,theta,varargin)
%HEATTHETA rsout l'quation de la chaleur avec la
%  theta-mthode.
%  [XH,UH]=HEATTHETA(XSPAN,TSPAN,NSTEP,MU,U0,G,F,THETA)
%  rsout l'quation de la chaleur
%  DU/DT - MU D^2U/DX^2 = F dans
%  ]XSPAN(1),XSPAN(2)[ x ]TSPAN(1),TSPAN(2)[ avec la
%  theta-mthode pour des conditions initiales
%  U(X,0)=U0(X) et des conditions de Dirichlet
%  U(X,T)=G(X,T) o X=XSPAN(1) et X=XSPAN(2). MU est
%  une constante positive. F=F(X,T), G=G(X,T) et
%  U0=U0(X) sont des fonctions inline, anonymes ou
%  dfinies par un M-file. NSTEP(1) est le nombre de
%  pas d'intgration en espace, NSTEP(2) est le nombre
%  de pas d'intgration en temps.
%  XH contient les noeuds de discrtisation.
%  UH contient la solution numrique au temps TSPAN(2).
%  [XH,UH]=HEATTHETA(XSPAN,TSPAN,NSTEP,MU,U0,G,F,...
%  THETA,P1,P2,...) passe les paramtres supplmentaires
%  P1,P2,... aux fonctions U0,G,F.
h  = (xspan(2)-xspan(1))/nstep(1);
dt = (tspan(2)-tspan(1))/nstep(2);
N = nstep(1)+1;
e = ones(N,1);
D = spdiags([-e 2*e -e],[-1,0,1],N,N);
I = speye(N);
A = I+mu*dt*theta*D/h^2;
An = I-mu*dt*(1-theta)*D/h^2;
A(1,:) = 0; A(1,1) = 1;
A(N,:) = 0; A(N,N) = 1;
xh = (linspace(xspan(1),xspan(2),N))';
fn = feval(f,xh,tspan(1),varargin{:});
un = feval(u0,xh,varargin{:});
[L,U]=lu(A);
for t = tspan(1)+dt:dt:tspan(2)
    fn1 = feval(f,xh,t,varargin{:});
    rhs = An*un+dt*(theta*fn1+(1-theta)*fn);
    temp = feval(g,[xspan(1),xspan(2)],t,varargin{:});
    rhs([1,N]) = temp;
    uh = L\rhs; uh = U\uh; fn = fn1; un = uh;
end
return
