function [xh,th,uh]=hyper(xspan,tspan,u0,ul,...
                          scheme,cfl,deltax,deltat)
% HYPER rsout une quation hyperbolique scalaire
% [XH,TH,UH]=HYPER(XSPAN,TSPAN,U0,UL,SCHEME,CFL,...
%                 DELTAX,DELTAT)
% rsout l'quation hyperbolique scalaire
%       DU/DT+ A * DU/DX=0
% sur ]XSPAN(1),XSPAN(2)[x]TSPAN(1),TSPAN(2)[
% avec A>0, la condition initiale  U(X,0)=U0(X) et
% la condition aux limites U(T)=UL(T) en XSPAN(1)
% avec diffrents schmas aux diffrences finies
%          1 Lax - Friedrichs
%          2 Lax - Wendroff
%          3 dcentr
% La vitesse de propagation `a' n'est pas requise en
% entre puisqu'elle peut tre dduite de
%  CFL = A * DELTAT / DELTAX
% Sortie: XH est le vecteur des noeuds en espace
% TH  est le vecteur des noeuds en temps
% UH est une matrice contenant la solution calcule
% UH(n,:) contient la solution au temps TT(n)
% U0 et UL peuvent tre des fonctions inline
% anonymes, ou dfinies par un M-file.

Nt=(tspan(2)-tspan(1))/deltat+1;
th=linspace(tspan(1),tspan(2),Nt);
Nx=(xspan(2)-xspan(1))/deltax+1;
xh=linspace(xspan(1),xspan(2),Nx);
u=zeros(Nt,Nx); cfl2=cfl*0.5; cfl21=1-cfl^2;
cflp1=cfl+1; cflm1=cfl-1;
uh(1,:)=feval(u0,xh);
for n=1:Nt-1
 uh(n+1,1)=feval(ul,th(n+1));
 if scheme == 1
% Lax Friedrichs
    for j=2:Nx-1
      uh(n+1,j)=0.5*(-cflm1*uh(n,j+1)+cflp1*uh(n,j-1));
    end
    j=Nx;
    uh(n+1,j)=0.5*(-cflm1*(2*uh(n,j)-uh(n,j-1))+...
        cflp1*uh(n,j-1));
 elseif scheme == 2
% Lax Wendroff
    for j=2:Nx-1
     uh(n+1,j)=cfl21*uh(n,j)+...
         cfl2*(cflm1*uh(n,j+1)+cflp1*uh(n,j-1));
    end
    j=Nx;
    uh(n+1,j)=cfl21*uh(n,j)+...
     cfl2*(cflm1*(2*uh(n,j)-uh(n,j-1))+cflp1*uh(n,j-1));
 elseif scheme ==3
% Upwind
   for j=2:Nx
        uh(n+1,j)=-cflm1*uh(n,j)+cfl*uh(n,j-1);
    end
 end
end
