function [zero,res,niter]=newton(fun,dfun,x0,tol,...
                                 nmax,varargin)
%NEWTON Cherche les zros d'une fonction.
%   ZERO=NEWTON(FUN,DFUN,X0,TOL,NMAX) tente de trouver
%   un zro ZERO de la fonction drivable FUN au
%   voisinage de X0 en utilisant la mthode de Newton.
%   FUN et sa drive DFUN prennent en entre un rel x
%   et retournent une valeur relle. Si la recherche
%   choue, un message d'erreur est affich.  FUN et
%   DFUN peuvent aussi tre des objets inline,  des
%   fonctions anonymes ou bien tre dfinies par des
%   M-files.
%   ZERO=NEWTON(FUN,DFUN,X0,TOL,NMAX,P1,P2,...) passe
%   les paramtres P1,P2,... aux fonctions:
%   FUN(X,P1,P2,...) et DFUN(X,P1,P2,...).
%   [ZERO,RES,NITER]= NEWTON(FUN,...)  retourne la
%   valeur approche du zro, la valeur du rsidu en
%   ZERO et le numro de l'itration  laquelle ZERO a
%   t calcul.
x = x0;
fx = feval(fun,x,varargin{:});
dfx = feval(dfun,x,varargin{:});
niter = 0; diff = tol+1;
while diff >= tol & niter < nmax
   niter = niter + 1;      diff = - fx/dfx;
   x = x + diff;           diff = abs(diff);
   fx = feval(fun,x,varargin{:});
   dfx = feval(dfun,x,varargin{:});
end
if (niter==nmax & diff > tol)
 fprintf(['La mthode de Newton est arrte ',...
 'sans converger avec la tolrance souhaite car\n',...
 'le nombre maximal d''itrations a t atteint\n']);
end
zero = x; res = fx;
return
