function [x,F,niter] = newtonsys(Ffun,Jfun,x0,tol,...
                                nmax, varargin)
%NEWTONSYS cherche un zro d'un systme non linaire
% [ZERO,F,NITER]=NEWTONSYS(FFUN,JFUN,X0,TOL,NMAX)
% tente de trouver le vecteur ZERO, racine d'un
% systme non linaire dfini dans FFUN et dont
% la matrice jacobienne est dfinie dans la
% fonction JFUN. La racine est cherche autour
% du vecteur X0.
% La variable F renvoie le rsidu dans ZERO
% NITER renvoie le nombre d'itrations ncessaires
% pour calculer ZERO. FFUN et JFUN sont des fonctions
% MATLAB dfinies dans des M-files.
niter = 0; err = tol + 1; x = x0;
while err >= tol & niter < nmax
    J = feval(Jfun,x,varargin{:});
    F = feval(Ffun,x,varargin{:});
    delta = - J\F;
    x = x + delta;
    err = norm(delta);
    niter = niter + 1;
end
F = norm(feval(Ffun,x,varargin{:}));
if (niter==nmax & err> tol)
   fprintf(['Pas de convergence dans le nombre',...
   ' d''iterations imparti\n ']);
   fprintf([' La valeur retourne a un rsidu',...
   ' relatif de %e\n'],F);
else
   fprintf(['La mthode a converg  l''itration',...
            ' %i avec un rsidu %e\n'],niter,F);
end
return
